summaryrefslogtreecommitdiff
path: root/indra/cmake/LLWindow.cmake
diff options
context:
space:
mode:
authorNicky <nicky.dasmijn@posteo.nl>2022-07-17 17:51:25 +0200
committerNicky <nicky.dasmijn@posteo.nl>2022-07-17 17:51:25 +0200
commit3f31d0b5a70af4ebf746d40d478b4e948e904a87 (patch)
tree140cd865990a6a892181612fd7ff1d9572c036a0 /indra/cmake/LLWindow.cmake
parentc66f444d2b3af7c5ea5220db5302b693bbc54f54 (diff)
Be more explicit: Rename use_conan_binary to use_system_binary, this will allow us to reuse the macro for more than just conan.
Diffstat (limited to 'indra/cmake/LLWindow.cmake')
-rw-r--r--indra/cmake/LLWindow.cmake4
1 files changed, 2 insertions, 2 deletions
diff --git a/indra/cmake/LLWindow.cmake b/indra/cmake/LLWindow.cmake
index 0136d56723..b36e970560 100644
--- a/indra/cmake/LLWindow.cmake
+++ b/indra/cmake/LLWindow.cmake
@@ -9,10 +9,10 @@ add_library( ll::SDL INTERFACE IMPORTED )
if (LINUX)
#Must come first as use_conan_binary can exit this file early
target_compile_definitions( ll::SDL INTERFACE LL_SDL=1)
- use_conan_binary(SDL)
+ use_system_binary(SDL)
use_prebuilt_binary(SDL)
target_include_directories( ll::SDL SYSTEM INTERFACE ${LIBS_PREBUILT_DIR}/include)
@@ -9,10 +9,10 @@ add_library( ll::SDL INTERFACE IMPORTED )
if (LINUX)
- #Must come first as use_conan_binary can exit this file early
+ #Must come first as use_system_binary can exit this file early
target_compile_definitions( ll::SDL INTERFACE LL_SDL=1)